diff --git a/TvEngine3/TVLibrary/TvPlugin/TvPlugin/TvNotifyManager.cs b/TvEngine3/TVLibrary/TvPlugin/TvPlugin/TvNotifyManager.cs
index f620961..089cee7 100644
--- a/TvEngine3/TVLibrary/TvPlugin/TvPlugin/TvNotifyManager.cs
+++ b/TvEngine3/TVLibrary/TvPlugin/TvPlugin/TvNotifyManager.cs
@@ -201,6 +201,92 @@
       return true;
     }
 
+    private bool NotifyChannelChange(TVProgramDescription tvProg, int onScreenTimeSeconds)
+    {
+        // TvHome.cs @ 1885
+            TVNotifyYesNoDialog tvNotifyDlg = (TVNotifyYesNoDialog)GUIWindowManager.GetWindow((int)GUIWindow.Window.WINDOW_DIALOG_TVNOTIFYYESNO);
+
+            TVProgramDescription notify = tvProg;
+            if (tvNotifyDlg == null || notify == null)
+            {
+              return false;
+            }
+            int minUntilStart = _preNotifyConfig / 60;
+            if (notify.StartTime > DateTime.Now)
+            {
+              if (minUntilStart > 1)
+              {
+                tvNotifyDlg.SetHeading(String.Format(GUILocalizeStrings.Get(1018), minUntilStart));
+              }
+              else
+              {
+                tvNotifyDlg.SetHeading(1019); // Program is about to begin
+              }
+            }
+            else
+            {
+              tvNotifyDlg.SetHeading(String.Format(GUILocalizeStrings.Get(1206), (DateTime.Now - notify.StartTime).Minutes.ToString()));
+            }
+            tvNotifyDlg.SetHeading("Switch to " + tvProg.Channel.DisplayName);
+            tvNotifyDlg.SetLine(1, notify.Title);
+            tvNotifyDlg.SetLine(2, notify.Description);
+            tvNotifyDlg.SetLine(4, String.Format(GUILocalizeStrings.Get(1207), notify.Channel.DisplayName));
+            Channel c = notify.Channel;
+            string strLogo = string.Empty;
+            if (c.IsTv)
+            {
+              strLogo = MediaPortal.Util.Utils.GetCoverArt(Thumbs.TVChannel, c.DisplayName);
+            }
+            else if (c.IsRadio)
+            {
+              strLogo = MediaPortal.Util.Utils.GetCoverArt(Thumbs.Radio, c.DisplayName);
+            }
+
+            tvNotifyDlg.SetImage(strLogo);
+            tvNotifyDlg.TimeOut = onScreenTimeSeconds;
+            //if (TVHome._playNotifyBeep)
+            {
+              MediaPortal.Util.Utils.PlaySound("notify.wav", false, true);
+            }
+            tvNotifyDlg.SetDefaultToYes(true);
+            tvNotifyDlg.DoModal(GUIWindowManager.ActiveWindow);
+
+            if (tvNotifyDlg.IsConfirmed)
+            {
+                return true;
+            }
+            else
+            {
+                return false;
+            }
+    }
+
+    private bool PausePlaybackDelayed(int pauseDelayMilliseconds)
+    {
+        SleepYield(pauseDelayMilliseconds);
+        g_Player.Pause();   
+        Log.Info("Pausing g_player");
+
+        return true;
+    }
+
+    private void SleepYield(int sleepMilliseconds)
+    {
+        if (sleepMilliseconds < 1)
+        {
+            sleepMilliseconds = 1;
+        }
+
+        int millisecondsYieldTime = 100;
+        int elapsedCountMilliseconds = 0;
+        while ((elapsedCountMilliseconds) <= (sleepMilliseconds))
+        {
+            g_Player.Process(); 
+            Thread.Sleep(millisecondsYieldTime);
+            elapsedCountMilliseconds += millisecondsYieldTime;
+        }
+    }
+
     private void ProcessNotifies(DateTime preNotifySecs)
     {
       if (_notifiesListChanged)
@@ -212,8 +298,10 @@
       {
         foreach (Program program in _notifiesList)
         {
-          if (preNotifySecs > program.StartTime)
-          {
+          // switching now, so switch near program start time
+          //if (preNotifySecs > program.StartTime)
+          if (System.DateTime.Now.AddSeconds(90) > program.StartTime)
+            {
             Log.Info("Notify {0} on {1} start {2}", program.Title, program.ReferencedChannel().DisplayName,
                      program.StartTime);
             program.Notify = false;
@@ -233,6 +321,44 @@
             GUIGraphicsContext.SendMessage(msg);
             msg = null;
             Log.Info("send notify done");
+
+            if (NotifyChannelChange(tvProg, 30))
+            {
+                Channel channel = tvProg.Channel;
+                if (channel.IsTv)
+                {
+                    MediaPortal.GUI.Library.GUIWindowManager.ActivateWindow((int)MediaPortal.GUI.Library.GUIWindow.Window.WINDOW_TVFULLSCREEN);
+                    if (g_Player.Paused)
+                    {
+                        GUIWaitCursor.EnableControl(g_Player.GetHDC(), 0);
+                        GUIWaitCursor.Show();
+                        int oldVolume = g_Player.Volume;
+                        g_Player.Volume = 0;
+                        TVHome.ViewChannel(channel);
+                        g_Player.ShowFullScreenWindowTVDefault();
+
+                        PausePlaybackDelayed(5000);
+
+                        g_Player.Volume = oldVolume;
+                        GUIWaitCursor.Hide();
+                    }
+                    else
+                    {
+                        TVHome.ViewChannel(channel);
+                        g_Player.ShowFullScreenWindow();
+                    }
+                }
+                else if (channel.IsRadio)
+                {
+                    MediaPortal.GUI.Library.GUIWindowManager.ActivateWindow((int)MediaPortal.GUI.Library.GUIWindow.Window.WINDOW_RADIO);
+                    Radio.CurrentChannel = channel;
+                    Radio.Play();
+                }
+
+                //// Now set a bookmark to help those who are pausing or wishing to go back in the buffer
+                MediaPortal.GUI.Video.GUIVideoFullscreen videoWindow = (MediaPortal.GUI.Video.GUIVideoFullscreen)GUIWindowManager.GetWindow((int)MediaPortal.GUI.Library.GUIWindow.Window.WINDOW_FULLSCREEN_VIDEO);
+                videoWindow.CreateBookmark();
+            }
             return;
           }
         }
